@@ -24,7 +24,7 @@ class AI21Object:
                 if isinstance(value, dict):
                     setattr(self, key, construct_ai21_object(value))
                 elif isinstance(value, list):
-                    setattr(self, key, [AI21Object(i) for i in value])
+                    setattr(self, key, [construct_ai21_object(i) for i in value])
                 else:
                     setattr(self, key, value)
 
